@@ -1,7 +1,7 @@
 package HTML::FormFu;
 
 use strict;
-our $VERSION = '2.03'; # TRIAL VERSION
+our $VERSION = '2.04'; # TRIAL VERSION
 
 use Moose;
 use MooseX::Attribute::FormFuChained;
@@ -51,8 +51,7 @@ use HTML::FormFu::Util qw(
 );
 
 use Clone ();
-use List::Util qw( first );
-use List::MoreUtils qw( any none uniq );
+use List::Util 1.45 qw( first any none uniq );
 use Scalar::Util qw( blessed weaken reftype );
 use Carp qw( croak );
 
@@ -1223,7 +1222,7 @@ HTML::FormFu - HTML Form Creation, Rendering and Validation Framework
 
 =head1 VERSION
 
-version 2.03
+version 2.04
 
 =head1 SYNOPSIS
 
@@ -3254,6 +3253,12 @@ Doug Orleans
 
 Matthias Dietrich
 
+Dean Hamstead
+
+Karen Etheridge
+
+Nigel Metheringham
+
 Based on the original source code of L<HTML::Widget>, by Sebastian Riedel,
 C<sri@oook.de>.
 
