@@ -1,7 +1,7 @@
 package HTML::FormFu::Element::Date;
 
 use strict;
-our $VERSION = '2.03'; # TRIAL VERSION
+our $VERSION = '2.04'; # TRIAL VERSION
 
 use Moose;
 use MooseX::Attribute::FormFuChained;
@@ -15,7 +15,7 @@ use DateTime::Format::Natural;
 use DateTime::Locale;
 use Moose::Util qw( apply_all_roles );
 use Scalar::Util qw( blessed );
-use List::MoreUtils qw( all none uniq );
+use List::Util 1.45 qw( all none uniq );
 use Carp qw( croak );
 
 __PACKAGE__->mk_attrs(qw( day  month  year ));
@@ -499,7 +499,7 @@ HTML::FormFu::Element::Date - 3 select menu multi-field
 
 =head1 VERSION
 
-version 2.03
+version 2.04
 
 =head1 SYNOPSIS
 
