@@ -1,12 +1,12 @@
 package HTML::FormFu::Role::CustomRoles;
 
 use strict;
-our $VERSION = '2.03'; # TRIAL VERSION
+our $VERSION = '2.04'; # TRIAL VERSION
 
 use Moose::Role;
 use Moose::Util qw( ensure_all_roles );
 
-use List::MoreUtils qw( uniq );
+use List::Util 1.45 qw( uniq );
 
 has _roles => (
     is      => 'rw',
